==> cramr_ui_lib-1.0.17.tar.gz: test/routes/streak_congratulation_route_test.dart <==
import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/practice_session.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/streak_congratulation_route.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  testWidgets('test 1st day streak', (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController = AdsController(MobileAds.instance);
    SettingsController settingsController = SettingsController(
        SettingsService(prefs), ThemeMode.dark, prefs, NotificationService());
    await settingsController.loadSettings();
    settingsController.streakEngine.addSession(PracticeSession(DateTime.now(),
        _mode, _tense, _randomIndicative, StudyMethod.writtenMethod));
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(
            create: (BuildContext context) {
              var model = VerbTestModel();
              model.initialise(_randomIndicative, _randomPronouns,
                  _randomInfinitive, 'fr', 'translation', _mode, _tense);
              int i = 0;
              for (var element in _randomIndicative) {
                model.add(element, i++);
              }
              return model;
            },
          ),
          Provider<AdsController?>(
            create: (BuildContext context) {
              return adsController;
            },
          )
        ],
        child: MaterialApp(
          home: StreakCongratulationRoute(
            settingsController,
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
          ),
        )));
    await tester.pumpAndSettle(const Duration(milliseconds: 600));
    Finder scrollKey = find.byKey(const Key('congratulationScrollViewKey'));
    expect(scrollKey, findsOneWidget);
    Finder numberOneFinder = find.text('1');
    expect(numberOneFinder, findsOneWidget);
    Finder jeOefendeAlFinder = find.text('Je oefende al');
    Finder dagenOpRijFinder = find.text('dag(en) op rij');
    Finder numberTwoFinder = find.text('2');
    expect(jeOefendeAlFinder, findsOneWidget);
    expect(dagenOpRijFinder, findsOneWidget);
    expect(numberTwoFinder, findsNothing);
  });

  testWidgets('test 2nd day streak', (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 2});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController = AdsController(MobileAds.instance);
    SettingsController settingsController = SettingsController(
        SettingsService(prefs), ThemeMode.dark, prefs, NotificationService());
    await settingsController.loadSettings();
    settingsController.streakEngine.addSession(PracticeSession(
        DateTime.now().subtract(const Duration(days: 1)),
        _mode,
        _tense,
        _randomIndicative,
        StudyMethod.writtenMethod));
    settingsController.streakEngine.addSession(PracticeSession(DateTime.now(),
        _mode, _tense, _randomIndicative, StudyMethod.writtenMethod));
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(
            create: (BuildContext context) {
              var model = VerbTestModel();
              model.initialise(_randomIndicative, _randomPronouns,
                  _randomInfinitive, 'fr', 'translation', _mode, _tense);
              int i = 0;
              for (var element in _randomIndicative) {
                model.add(element, i++);
              }
              return model;
            },
          ),
          Provider<AdsController?>(
            create: (BuildContext context) {
              return adsController;
            },
          )
        ],
        child: MaterialApp(
          home: StreakCongratulationRoute(
            settingsController,
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
          ),
        )));
    await tester.pumpAndSettle(const Duration(milliseconds: 600));
    Finder scrollKey = find.byKey(const Key('congratulationScrollViewKey'));
    expect(scrollKey, findsOneWidget);
    Finder numberOneFinder = find.text('1');
    expect(numberOneFinder, findsNothing);
    Finder jeOefendeAlFinder = find.text('Je oefende al');
    Finder dagenOpRijFinder = find.text('dag(en) op rij');
    Finder numberTwoFinder = find.text('2');
    expect(jeOefendeAlFinder, findsOneWidget);
    expect(dagenOpRijFinder, findsOneWidget);
    expect(numberTwoFinder, findsOneWidget);
  });
}

==> cramr_ui_lib-2.0.0.tar.gz: test/routes/streak_congratulation_route_test.dart <==
import 'package:cramr_ui_lib/ads/ads_controller.dart';
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/model/practice_session.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/streak_congratulation_route.dart';
import 'package:cramr_ui_lib/settings/client_context.dart';
import 'package:cramr_ui_lib/settings/notification_service.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:google_mobile_ads/google_mobile_ads.dart';
import 'package:provider/provider.dart';
import 'package:shared_preferences/shared_preferences.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';
const String _mode = 'mode';
const String _tense = 'tense';

void main() {
  testWidgets('test 1st day streak', (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 1});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController = AdsController(MobileAds.instance);
    SettingsController settingsController = SettingsController(
        SettingsService(prefs),
        ThemeMode.dark,
        prefs,
        NotificationService(),
        ClientContext(ClientApp.verbomatiqueSecondaire));
    await settingsController.loadSettings();
    settingsController.streakEngine.addSession(PracticeSession(DateTime.now(),
        _mode, _tense, _randomIndicative, StudyMethod.writtenMethod));
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(
            create: (BuildContext context) {
              var model = VerbTestModel();
              model.initialise(_randomIndicative, _randomPronouns,
                  _randomInfinitive, 'fr', 'translation', _mode, _tense);
              int i = 0;
              for (var element in _randomIndicative) {
                model.add(element, i++);
              }
              return model;
            },
          ),
          Provider<AdsController?>(
            create: (BuildContext context) {
              return adsController;
            },
          )
        ],
        child: MaterialApp(
          home: StreakCongratulationRoute(
            settingsController,
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
          ),
        )));
    await tester.pumpAndSettle(const Duration(milliseconds: 600));
    Finder scrollKey = find.byKey(const Key('congratulationScrollViewKey'));
    expect(scrollKey, findsOneWidget);
    Finder numberOneFinder = find.text('1');
    expect(numberOneFinder, findsOneWidget);
    Finder jeOefendeAlFinder = find.text('Je oefende al');
    Finder dagenOpRijFinder = find.text('dag(en) op rij');
    Finder numberTwoFinder = find.text('2');
    expect(jeOefendeAlFinder, findsOneWidget);
    expect(dagenOpRijFinder, findsOneWidget);
    expect(numberTwoFinder, findsNothing);
  });

  testWidgets('test 2nd day streak', (WidgetTester tester) async {
    SharedPreferences.setMockInitialValues(<String, Object>{'counter': 2});
    SharedPreferences prefs = await SharedPreferences.getInstance();
    AdsController? adsController = AdsController(MobileAds.instance);
    SettingsController settingsController = SettingsController(
        SettingsService(prefs),
        ThemeMode.dark,
        prefs,
        NotificationService(),
        ClientContext(ClientApp.verbomatiqueSecondaire));
    await settingsController.loadSettings();
    settingsController.streakEngine.addSession(PracticeSession(
        DateTime.now().subtract(const Duration(days: 1)),
        _mode,
        _tense,
        _randomIndicative,
        StudyMethod.writtenMethod));
    settingsController.streakEngine.addSession(PracticeSession(DateTime.now(),
        _mode, _tense, _randomIndicative, StudyMethod.writtenMethod));
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(
            create: (BuildContext context) {
              var model = VerbTestModel();
              model.initialise(_randomIndicative, _randomPronouns,
                  _randomInfinitive, 'fr', 'translation', _mode, _tense);
              int i = 0;
              for (var element in _randomIndicative) {
                model.add(element, i++);
              }
              return model;
            },
          ),
          Provider<AdsController?>(
            create: (BuildContext context) {
              return adsController;
            },
          )
        ],
        child: MaterialApp(
          home: StreakCongratulationRoute(
            settingsController,
            safeBannerAdWidget: const SafeBannerAdWidget(
              adUnitId: '',
              adRequest: AdRequest(),
            ),
          ),
        )));
    await tester.pumpAndSettle(const Duration(milliseconds: 600));
    Finder scrollKey = find.byKey(const Key('congratulationScrollViewKey'));
    expect(scrollKey, findsOneWidget);
    Finder numberOneFinder = find.text('1');
    expect(numberOneFinder, findsNothing);
    Finder jeOefendeAlFinder = find.text('Je oefende al');
    Finder dagenOpRijFinder = find.text('dag(en) op rij');
    Finder numberTwoFinder = find.text('2');
    expect(jeOefendeAlFinder, findsOneWidget);
    expect(dagenOpRijFinder, findsOneWidget);
    expect(numberTwoFinder, findsOneWidget);
  });
}
